import React, { useMemo, useState } from 'react';
import { StyleSheet } from 'react-native';
import { useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import View from "../view";
import TouchableOpacity from "../touchableOpacity";
/**
 * @description: ExpandableSection component to render expanded section below or above the sectionHeader
 * @example: https://github.com/wix/react-native-ui-lib/blob/master/demo/src/screens/componentScreens/ExpandableSectionScreen.tsx
 * @gif: https://github.com/wix/react-native-ui-lib/blob/master/demo/showcase/ExpandableSection/ExpandableSection.gif?raw=true
 */

function ExpandableSection(props) {
  const {
    expanded,
    sectionHeader,
    onPress,
    children,
    top,
    testID
  } = props;
  const [height, setHeight] = useState(0);
  const animatedHeight = useSharedValue(0);
  const onLayout = event => {
    const onLayoutHeight = event.nativeEvent.layout.height;
    if (onLayoutHeight > 0 && height !== onLayoutHeight) {
      setHeight(onLayoutHeight);
    }
  };
  const expandableStyle = useAnimatedStyle(() => {
    animatedHeight.value = expanded ? withTiming(height) : withTiming(0);
    return {
      height: animatedHeight.value
    };
  }, [expanded, height]);
  const style = useMemo(() => [styles.hidden, expandableStyle], [expandableStyle]);
  const accessibilityState = useMemo(() => {
    return {
      expanded
    };
  }, [expanded]);
  const renderChildren = () => {
    return <View reanimated style={style}>
        <View absH onLayout={onLayout}>
          {children}
        </View>
      </View>;
  };
  return <View style={styles.hidden}>
      {top && renderChildren()}
      <TouchableOpacity onPress={onPress} testID={testID} accessibilityState={accessibilityState}>
        {sectionHeader}
      </TouchableOpacity>
      {!top && renderChildren()}
    </View>;
}
export default ExpandableSection;
const styles = StyleSheet.create({
  hidden: {
    overflow: 'hidden'
  }
});