import _isEmpty from "lodash/isEmpty";
import { fireEvent } from '@testing-library/react-native';
import { useComponentDriver } from "../../testkit/new/Component.driver";
import { TextDriver } from "../text/Text.driver.new";
import { usePressableDriver } from "../../testkit/new/usePressable.driver";
export const TextFieldDriver = props => {
  const driver = usePressableDriver(useComponentDriver(props));
  const floatingPlaceholderDriver = TextDriver({
    renderTree: props.renderTree,
    testID: `${props.testID}.floatingPlaceholder`
  });
  const labelDriver = TextDriver({
    renderTree: props.renderTree,
    testID: `${props.testID}.label`
  });
  const validationMsgDriver = TextDriver({
    renderTree: props.renderTree,
    testID: `${props.testID}.validationMessage`
  });
  const charCounterDriver = TextDriver({
    renderTree: props.renderTree,
    testID: `${props.testID}.charCounter`
  });
  const getValue = () => {
    return driver.getElement().props.value ?? driver.getElement().props.defaultValue;
  };
  const changeText = text => {
    fireEvent.changeText(driver.getElement(), text);
  };
  const focus = () => {
    fireEvent(driver.getElement(), 'focus');
  };
  const blur = () => {
    fireEvent(driver.getElement(), 'blur');
  };
  const isEnabled = () => {
    return !driver.getElement().props.accessibilityState?.disabled;
  };
  const getPlaceholder = () => {
    const exists = () => {
      const hasPlaceholder = !!driver.getElement().props.placeholder;
      const hasText = !!getValue();
      return hasPlaceholder && (!hasText || hasText && floatingPlaceholderDriver.exists());
    };
    const getText = () => {
      if (exists()) {
        return driver.getElement().props.placeholder;
      }
    };
    return {
      ...floatingPlaceholderDriver,
      exists,
      getText
    };
  };
  const getLabel = () => {
    const exists = () => {
      return labelDriver.exists() && !floatingPlaceholderDriver.exists();
    };
    return {
      ...labelDriver,
      exists
    };
  };
  const getValidationMessage = () => {
    const exists = () => {
      return validationMsgDriver.exists() && !_isEmpty(validationMsgDriver.getText());
    };
    return {
      ...validationMsgDriver,
      exists
    };
  };
  const getCharCounter = () => {
    return charCounterDriver;
  };
  return {
    ...driver,
    getValue,
    changeText,
    focus,
    blur,
    isEnabled,
    getPlaceholder,
    getLabel,
    getValidationMessage,
    getCharCounter
  };
};